==> com.liferay.app.builder.web-1.0.2.jar: META-INF/resources/js/utils/generateDataDefinitionFieldName.es.js <==
Liferay.Loader.define("app-builder-web@1.0.2/js/utils/generateDataDefinitionFieldName.es", ['module', 'exports', 'require', 'dynamic-data-mapping-form-renderer/js/util/fields.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _fields = require("dynamic-data-mapping-form-renderer/js/util/fields.es");

  /**
   * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
   *
   * This library is free software; you can redistribute it and/or modify it under
   * the terms of the GNU Lesser General Public License as published by the Free
   * Software Foundation; either version 2.1 of the License, or (at your option)
   * any later version.
   *
   * This library is distributed in the hope that it will be useful, but WITHOUT
   * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
   * details.
   */
  var findFieldByName = function findFieldByName(dataDefinitionFields, fieldName) {
    return dataDefinitionFields.find(function (_ref) {
      var name = _ref.name;
      return name === fieldName;
    });
  };

  var _default = function _default(_ref2, fieldTypeName) {
    var dataDefinitionFields = _ref2.dataDefinitionFields;
    var counter = 0;
    var name = (0, _fields.normalizeFieldName)(fieldTypeName);

    while (findFieldByName(dataDefinitionFields, name)) {
      name = (0, _fields.normalizeFieldName)("".concat(fieldTypeName).concat(++counter));
    }

    return name;
  };

  exports["default"] = _default;
  //# sourceMappingURL=generateDataDefinitionFieldName.es.js.map
});
//# sourceMappingURL=generateDataDefinitionFieldName.es.js.map

==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/utils/generateDataDefinitionFieldName.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/utils/generateDataDefinitionFieldName.es", ['module', 'exports', 'require', 'dynamic-data-mapping-form-renderer'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _dynamicDataMappingFormRenderer = require("dynamic-data-mapping-form-renderer");

  /**
   * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
   *
   * This library is free software; you can redistribute it and/or modify it under
   * the terms of the GNU Lesser General Public License as published by the Free
   * Software Foundation; either version 2.1 of the License, or (at your option)
   * any later version.
   *
   * This library is distributed in the hope that it will be useful, but WITHOUT
   * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
   * details.
   */
  var findFieldByName = function findFieldByName(dataDefinitionFields, fieldName) {
    return dataDefinitionFields.find(function (_ref) {
      var name = _ref.name;
      return name === fieldName;
    });
  };

  var _default = function _default(_ref2, fieldTypeName) {
    var dataDefinitionFields = _ref2.dataDefinitionFields;
    var counter = 0;
    var name = (0, _dynamicDataMappingFormRenderer.normalizeFieldName)(fieldTypeName);

    while (findFieldByName(dataDefinitionFields, name)) {
      name = (0, _dynamicDataMappingFormRenderer.normalizeFieldName)("".concat(fieldTypeName).concat(++counter));
    }

    return name;
  };

  exports["default"] = _default;
  //# sourceMappingURL=generateDataDefinitionFieldName.es.js.map
});
//# sourceMappingURL=generateDataDefinitionFieldName.es.js.map
